@@ -1,7 +1,7 @@
 import os
 
-import dotenv
 import redis
+import dotenv
 
 
 dotenv.load_dotenv()
@@ -14,7 +14,7 @@ def get_redis_connection(**kwargs) -> redis.Redis:
     # environment variable, we'll create the Redis client from the URL.
     url = kwargs.pop("url", URL)
     if url:
-        return redis.from_url(url, **kwargs)
+        return redis.Redis.from_url(url, **kwargs)
 
     # Decode from UTF-8 by default
     if "decode_responses" not in kwargs:
